==> roughpy-0.0.8.tar.gz: roughpy-0.0.8/tests/algebra/test_free_multiply_functions.py <==
import pytest

import roughpy as rp

import numpy as np
from numpy.testing import assert_array_equal, assert_array_almost_equal


@pytest.fixture
def tensor_context():
    return rp.get_context(2, 2, rp.DPReal)


@pytest.fixture
def tensor_data(rng, tensor_context):
    def generator():
        return rng.uniform(-1.0, 1.0, size=tensor_context.tensor_size(
            tensor_context.depth))

    return generator


def test_free_tensor_multiply_shuffles(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    sh1 = rp.ShuffleTensor(d1, ctx=tensor_context)
    sh2 = rp.ShuffleTensor(d2, ctx=tensor_context)

    result = rp.free_multiply(sh1, sh2)

    ft1 = rp.FreeTensor(d1, ctx=tensor_context)
    ft2 = rp.FreeTensor(d2, ctx=tensor_context)
    expected = ft1 * ft2

    assert_array_equal(result, expected)


def test_shuffle_multiply_two_frees(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    ft1 = rp.FreeTensor(d1, ctx=tensor_context)
    ft2 = rp.FreeTensor(d2, ctx=tensor_context)

    result = rp.shuffle_multiply(ft1, ft2)

    sh1 = rp.ShuffleTensor(d1, ctx=tensor_context)
    sh2 = rp.ShuffleTensor(d2, ctx=tensor_context)
    expected = sh1 * sh2

    assert_array_equal(result, expected)


def test_adjoint_of_left_multiplication(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    width = tensor_context.width
    depth = tensor_context.depth
    sizes = [0, 1]
    for i in range(depth):
        sizes.append(sizes[-1]*width)

    t1 = rp.FreeTensor(d1, ctx=tensor_context)
    t2 = rp.FreeTensor(d2, ctx=tensor_context)

    result = rp.adjoint_to_free_multiply(t1, t2)

    expected_data = np.zeros(tensor_context.tensor_size(tensor_context.depth))
    for entry in t2:
        key = entry.key()
        for i in range(key.degree()+1):
            left, right = entry.key().split_n(i)
            expected_data[right.to_index()] += d1[left.to_index()]*entry.value().to_float()


    expected = rp.FreeTensor(expected_data, ctx=tensor_context)
    assert_array_equal(result, expected)
    #assert result.size() == t1.size()

==> roughpy-0.2.0.tar.gz: roughpy-0.2.0/tests/algebra/test_free_multiply_functions.py <==
import pytest

import roughpy as rp

import numpy as np
from numpy.testing import assert_array_almost_equal


@pytest.fixture
def tensor_context():
    return rp.get_context(2, 2, rp.DPReal)


@pytest.fixture
def tensor_data(rng, tensor_context):
    def generator():
        return rng.uniform(-1.0, 1.0, size=tensor_context.tensor_size(
            tensor_context.depth))

    return generator


def test_free_tensor_multiply_shuffles(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    sh1 = rp.ShuffleTensor(d1, ctx=tensor_context)
    sh2 = rp.ShuffleTensor(d2, ctx=tensor_context)

    result = rp.free_multiply(sh1, sh2)

    ft1 = rp.FreeTensor(d1, ctx=tensor_context)
    ft2 = rp.FreeTensor(d2, ctx=tensor_context)
    expected = ft1 * ft2

    assert_array_almost_equal(result, expected)


def test_shuffle_multiply_two_frees(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    ft1 = rp.FreeTensor(d1, ctx=tensor_context)
    ft2 = rp.FreeTensor(d2, ctx=tensor_context)

    result = rp.shuffle_multiply(ft1, ft2)

    sh1 = rp.ShuffleTensor(d1, ctx=tensor_context)
    sh2 = rp.ShuffleTensor(d2, ctx=tensor_context)
    expected = sh1 * sh2

    assert_array_almost_equal(result, expected)


def test_adjoint_of_left_multiplication(tensor_data, tensor_context):
    d1 = tensor_data()
    d2 = tensor_data()
    width = tensor_context.width
    depth = tensor_context.depth
    sizes = [0, 1]
    for i in range(depth):
        sizes.append(sizes[-1]*width)

    t1 = rp.FreeTensor(d1, ctx=tensor_context)
    t2 = rp.FreeTensor(d2, ctx=tensor_context)

    result = rp.adjoint_to_free_multiply(t1, t2)

    expected_data = np.zeros(tensor_context.tensor_size(tensor_context.depth))
    for entry in t2:
        key = entry.key()
        for i in range(key.degree()+1):
            left, right = entry.key().split_n(i)
            expected_data[right.to_index()] += d1[left.to_index()]*entry.value().to_float()


    expected = rp.FreeTensor(expected_data, ctx=tensor_context)
    assert_array_almost_equal(result, expected)
    #assert result.size() == t1.size()
